Name:           grib_api
Version:        1.11.0
Release:        1%{?dist}
Summary:        WMO FM-92 GRIB (v1,v2) interface accessible from C and FORTRAN programs

Group:          Applications/System
License:        ASL 2.0
URL:            https://software.ecmwf.int/wiki/display/GRIB/Home
Source0:        https://software.ecmwf.int/wiki/download/attachments/3473437/grib_api-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  gcc-gfortran
BuildRequires:  netcdf-devel
BuildRequires:  jasper-devel
BuildRequires:  numpy
BuildRequires:  python2-devel

%description
The ECMWF GRIB API is an application program interface accessible from C
and FORTRAN programs developed for encoding and decoding WMO FM-92 GRIB
edition 1 and edition 2 messages. A useful set of command line tools is
also provided to give quick access to grib messages.

%package devel
Summary:    GRIB API development headers
Group:      Development/Languages
Requires:   %{name}%{?_isa} = %{version}-%{release}
Requires:   gcc-gfortran%{?_isa}
Requires:   jasper-devel%{?_isa}

%description devel
Header files and libraries for building a extension library

%package static
Summary:    GRIB API static libraries
Group:      Applications/System
Requires:   %{name}%{?_isa} = %{version}-%{release}
Requires:   %{name}-devel%{?_isa} = %{version}-%{release}

%description static
Static libraries for %{name}

%package -n python-%{name}
Summary:    GRIB API python interface

%description -n python-%{name}
%{summary}.


%prep
%setup -q
# Fix ksh path
sed -i -e 's,/usr/bin/ksh,/bin/ksh,' tools/grib1to2.txt


%build
%{configure} --with-ifs-samples=%{_datadir}/%{name}/ifs_samples \
  --enable-python --with-netcdf=%{_libdir} --with-pic
make #%{?_smp_mflags}


%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}

find %{buildroot} -name \*.la -delete

# Convert ISO88591 text to UTF-8
for file in `find %{buildroot}%{_datadir}/%{name}/definitions/`; do
    iconv -f ISO88591 -t utf-8 $file > $file.new && mv $file.new $file || rm -f $file.new
done

# Move %{_bindir}/parser because it conflicts with coda-client
mv %{buildroot}%{_bindir}/parser %{buildroot}%{_bindir}/grib-parser

# Give these files some normal permissions
chmod 644 README LICENSE COPYING ChangeLog AUTHORS

# Move the fortran module into _fmoddir
mkdir -p %{buildroot}%{_fmoddir}
mv %{buildroot}%{_includedir}/%{name}.mod %{buildroot}%{_fmoddir}


%clean
rm -rf %{buildroot}


%check
# ls.sh test is failing
# https://software.ecmwf.int/issues/browse/SUP-521
make check || true


%files
%doc README LICENSE COPYING ChangeLog AUTHORS
%{_bindir}/*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/definitions/
%doc %{_datadir}/%{name}/ifs_samples/
%doc %{_datadir}/%{name}/samples/
%{_libdir}/*.so.*

%files devel
%{_includedir}/*
%{_fmoddir}/%{name}.mod
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}_f90.pc

%files -n python-%{name}
%{python_sitearch}/*

%files static
%{_libdir}/*.a

%changelog
* Fri Aug 23 2013 Orion Poplawski <orion@cora.nwra.com> - 1.11.0-1
- Update to 1.11.0
- Build shared libraries
- Enable python support
- Run tests (but ignore failure for now)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.16-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Mar 8 2013 Orion Poplawski <orion@cora.nwra.com> - 1.9.16-7
- Build with -fPIC on ARM (bug #919614)

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.16-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.16-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jul 16 2012 Orion Poplawski <orion@cora.nwra.com> - 1.9.16-4
- Revert to /bin/ksh

* Mon Jul 9 2012 Orion Poplawski <orion@cora.nwra.com> - 1.9.16-3
- Definitions are not documentation
- Drop INSTALL from docs
- Add Requires jasper-devel to -devel package
- Don't change ksh path on Fedora 17+

* Fri Jul 6 2012 Orion Poplawski <orion@cora.nwra.com> - 1.9.16-2
- Build fortran interface

* Tue Mar 13 2012 Orion Poplawski <orion@cora.nwra.com> - 1.9.16-1
- Update to 1.9.16

* Sat Jan 14 2012 Orion Poplawski <orion@cora.nwra.com> - 1.9.9-2
- Fix ksh path

* Fri Jan 13 2012 Orion Poplawski <orion@cora.nwra.com> - 1.9.9-1
- Update to 1.9.9
- Fix directory ownership

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Feb 15 2010 Orion Poplawski <orion@cora.nwra.com> - 1.7.0-5
- Compile with -fPIC on x86_64 (bug #561914)

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sat Apr 04 2009 Jeroen van Meeuwen <j.van.meeuwen@ogd.nl> - 1.7.0-3
- Fix file conflict (#492936)

* Tue Mar 17 2009 Jeroen van Meeuwen <j.van.meeuwen@ogd.nl> - 1.7.0-1
- New upstream version

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Dec  3 2008 Patrice Dumas <pertusus@free.fr> 1.6.4-1
- update to 1.6.4

* Tue Sep 30 2008 Patrice Dumas <pertusus@free.fr> 1.6.1-1
- update to 1.6.1

* Sat Feb 23 2008 Patrice Dumas <pertusus@free.fr> 1.4.0-1
- update to 1.4.0

* Sat Dec 29 2007 Patrice Dumas <pertusus@free.fr> 1.3.0-1
- initial release
